@@ -7,8 +7,8 @@ use Carp;
 use Benchmark qw(timestr);
 use MRO::Compat;
 
-
-use base 'Test::Run::Base';
+use Moose;
+extends("Test::Run::Base");
 
 use Test::Run::Output;
 
@@ -25,11 +25,6 @@ avoid license complications.
 
 =cut
 
-
-__PACKAGE__->mk_accessors(qw(
-    output
-));
-
 sub _get_new_output
 {
     my ($self, $args) = @_;
@@ -455,7 +450,7 @@ sub _fail_other_report_tests_print_summary
 
     return $self->_obj_named_printf(
         ( "%(name)-\${max_namelen}s  "
-        . "%(estat)3s %(wstat)5s %(max)5s %(failed)4s "
+        . "%(estat)3s %(wstat)5s %(max_str)5s %(failed_str)4s "
         . "%(_defined_percent)6.2f%%  %(first_canon_string)s"
         ),
         $args->{test},
@@ -548,7 +543,7 @@ sub _report_test_progress__counter
     my $totals = $args->{totals};
 
     my $curr = $totals->seen;
-    my $next = $self->Strap->next();
+    my $next = $self->Strap->next_test_num();
 
     if ($curr > $next)
     {
