@@ -3,29 +3,17 @@ package Test::Run::Straps::EventWrapper;
 use strict;
 use warnings;
 
-use base 'Test::Run::Base';
+use Moose;
 
-__PACKAGE__->mk_accessors(qw(
-    _tp_result
-));
+use Test::Run::Base;
 
-=head1 NAME
+extends('Test::Run::Base');
 
-Test::Run::Straps::EventWrapper - a wrapper for a TAP::Parser::Result subclass
-which delegates to its methods and has its own methods.
-
-=head1 DESCRIPTION
-
-L<TAP::Parser>'s C<next()> method returns a sub-class of 
-L<TAP::Parser::Result>. However, we need to define our own methods
-on such objects. Since we cannot inherit from all the sub-classes, we
-have created this class which holds an instance of the actual events,
-delegates some methods to it, and defines some of its own methods.
-
-=cut
-
-__PACKAGE__->delegate_methods("_tp_result",
-    [qw(
+has '_tp_result' => 
+(
+    is => "rw",
+    isa => "Maybe[TAP::Parser::Result]",
+    handles => [qw(
         comment
         description
         directive
@@ -41,9 +29,24 @@ __PACKAGE__->delegate_methods("_tp_result",
         number
         raw
         tests_planned
-    )]
+    )],
 );
 
+=head1 NAME
+
+Test::Run::Straps::EventWrapper - a wrapper for a TAP::Parser::Result subclass
+which delegates to its methods and has its own methods.
+
+=head1 DESCRIPTION
+
+L<TAP::Parser>'s C<next()> method returns a sub-class of 
+L<TAP::Parser::Result>. However, we need to define our own methods
+on such objects. Since we cannot inherit from all the sub-classes, we
+have created this class which holds an instance of the actual events,
+delegates some methods to it, and defines some of its own methods.
+
+=cut
+
 sub _init
 {
     my $self = shift;
