@@ -3,10 +3,16 @@ package MyTestRun::Plug::Base;
 use strict;
 use warnings;
 
-use base 'Test::Run::Base::Struct';
+use Moose;
+
+extends(qw(
+    Test::Run::Base::Struct
+    ));
 
 my @fields = (qw(first last));
-__PACKAGE__->mk_accessors(@fields);
+
+has 'first' => (is => "rw");
+has 'last' => (is => "rw");
 
 sub _get_private_fields
 {
